==> apache-mxnet-src-1.8.0-incubating.tar.gz: apache-mxnet-src-1.8.0-incubating/docs/static_site/src/_includes/get_started/linux/python/cpu/pip.md <==
WARNING: the following PyPI package names are provided for your convenience but
they point to packages that are *not* provided nor endorsed by the Apache
Software Foundation. As such, they might contain software components with more
restrictive licenses than the Apache License and you'll need to decide whether
they are appropriate for your usage. The packages linked here contain GPL GCC
Runtime Library components. Like all Apache Releases, the official Apache MXNet
(incubating) releases consist of source code only and are found at the [Download
page](https://mxnet.apache.org/get_started/download).

Run the following command:

<div class="v1-7-0">
{% highlight bash %}
pip install mxnet
{% endhighlight %}

Start from 1.7.0 release, oneDNN(previously known as: MKL-DNN/DNNL) is enabled
in pip packages by default.

oneAPI Deep Neural Network Library (oneDNN) is an open-source cross-platform
performance library of basic building blocks for deep learning applications.
The library is optimized for Intel Architecture Processors, Intel Processor
Graphics and Xe architecture-based Graphics. Support for other architectures
such as Arm* 64-bit Architecture (AArch64) and OpenPOWER* Power ISA (PPC64) is
experimental.

oneDNN is intended for deep learning applications and framework developers
interested in improving application performance on Intel CPUs and GPUs, more
details can be found <a href="https://github.com/oneapi-src/oneDNN">here</a>.

You can find performance numbers in the
<a href="https://mxnet.apache.org/versions/1.6/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

To install native MXNet without oneDNN, run the following command:

{% highlight bash %}
pip install mxnet-native
{% endhighlight %}

</div> <!-- End of v1-7-0 -->

<div class="v1-6-0">
{% highlight bash %}
pip install mxnet==1.6.0
{% endhighlight %}

MKL-DNN enabled pip packages are optimized for Intel hardware. You can find
performance numbers in the
<a href="https://mxnet.apache.org/versions/1.6/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

{% highlight bash %}
pip install mxnet-mkl==1.6.0
{% endhighlight %}

</div> <!-- End of v1-6-0 -->

<div class="v1-5-1">
{% highlight bash %}
pip install mxnet==1.5.1
{% endhighlight %}

MKL-DNN enabled pip packages are optimized for Intel hardware. You can find
performance numbers in the
<a href="https://mxnet.apache.org/versions/1.6/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

{% highlight bash %}
pip install mxnet-mkl==1.5.1
{% endhighlight %}

</div> <!-- End of v1-5-1 -->

<div class="v1-4-1">

{% highlight bash %}
pip install mxnet==1.4.1
{% endhighlight %}

MKL-DNN enabled pip packages are optimized for Intel hardware. You can find
performance numbers in the
<a href="https://mxnet.apache.org/versions/1.6/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

{% highlight bash %}
pip install mxnet-mkl==1.4.1
{% endhighlight %}

</div> <!-- End of v1-4-1 -->
<div class="v1-3-1">

{% highlight bash %}
pip install mxnet==1.3.1
{% endhighlight %}

MKL-DNN enabled pip packages are optimized for Intel hardware. You can find
performance numbers in the
<a href="https://mxnet.apache.org/versions/1.6/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

{% highlight bash %}
pip install mxnet-mkl==1.3.1
{% endhighlight %}

</div> <!-- End of v1-3-1 -->
<div class="v1-2-1">

{% highlight bash %}
pip install mxnet==1.2.1
{% endhighlight %}

MKL-DNN enabled pip packages are optimized for Intel hardware. You can find
performance numbers in the
<a href="https://mxnet.apache.org/versions/1.6/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

{% highlight bash %}
pip install mxnet-mkl==1.2.1
{% endhighlight %}

</div> <!-- End of v1-2-1 -->

<div class="v1-1-0">

{% highlight bash %}
pip install mxnet==1.1.0
{% endhighlight %}

</div> <!-- End of v1-1-0-->

<div class="v1-0-0">

{% highlight bash %}
pip install mxnet==1.0.0
{% endhighlight %}

</div> <!-- End of v1-0-0-->


<div class="v0-12-1">

{% highlight bash %}
pip install mxnet==0.12.1
{% endhighlight %}

For MXNet 0.12.0:

{% highlight bash %}
pip install mxnet==0.12.0
{% endhighlight %}

</div> <!-- End of v0-12-1-->

<div class="v0-11-0">

{% highlight bash %}
pip install mxnet==0.11.0
{% endhighlight %}

</div> <!-- End of v0-11-0-->

<br>


{% include /get_started/pip_snippet.md %}

==> apache-mxnet-src-1.9.1-incubating.tar.gz: apache-mxnet-src-1.9.1-incubating/docs/static_site/src/_includes/get_started/linux/python/cpu/pip.md <==
WARNING: the following PyPI package names are provided for your convenience but
they point to packages that are *not* provided nor endorsed by the Apache
Software Foundation. As such, they might contain software components with more
restrictive licenses than the Apache License and you'll need to decide whether
they are appropriate for your usage. The packages linked here contain GPL GCC
Runtime Library components. Like all Apache Releases, the official Apache MXNet
(incubating) releases consist of source code only and are found at the [Download
page](https://mxnet.apache.org/get_started/download).

Run the following command:

<div class="v1-9-0">
{% highlight bash %}
pip install mxnet
{% endhighlight %}

</div> <!-- End of v1-9-0 -->

<div class="v1-8-0">
{% highlight bash %}
pip install mxnet==1.8.0.post0
{% endhighlight %}

Start from 1.7.0 release, oneDNN(previously known as: MKL-DNN/DNNL) is enabled
in pip packages by default.

oneAPI Deep Neural Network Library (oneDNN) is an open-source cross-platform
performance library of basic building blocks for deep learning applications.
The library is optimized for Intel Architecture Processors, Intel Processor
Graphics and Xe architecture-based Graphics. Support for other architectures
such as Arm* 64-bit Architecture (AArch64) and OpenPOWER* Power ISA (PPC64) is
experimental.

oneDNN is intended for deep learning applications and framework developers
interested in improving application performance on Intel CPUs and GPUs, more
details can be found <a href="https://github.com/oneapi-src/oneDNN">here</a>.

You can find performance numbers in the
<a href="https://mxnet.apache.org/versions/1.8.0/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

To install native MXNet without oneDNN, run the following command:

{% highlight bash %}
pip install mxnet-native==1.8.0.post0
{% endhighlight %}

</div> <!-- End of v1-8-0 -->

<div class="v1-7-0">
{% highlight bash %}
pip install mxnet==1.7.0.post2
{% endhighlight %}

Start from 1.7.0 release, oneDNN(previously known as: MKL-DNN/DNNL) is enabled
in pip packages by default.

oneAPI Deep Neural Network Library (oneDNN) is an open-source cross-platform
performance library of basic building blocks for deep learning applications.
The library is optimized for Intel Architecture Processors, Intel Processor
Graphics and Xe architecture-based Graphics. Support for other architectures
such as Arm* 64-bit Architecture (AArch64) and OpenPOWER* Power ISA (PPC64) is
experimental.

Please note that the Linux CPU pip wheels for AArch64 platforms are built with
oneDNN with Arm Performance Libraries (APL) integrated. Because APL's license
is not compatible with Apache license, you would need to
<a href="https://developer.arm.com/tools-and-software/server-and-hpc/compile/arm-compiler-for-linux/arm-performance-libraries">manually install</a> APL
in your system.

oneDNN is intended for deep learning applications and framework developers
interested in improving application performance on Intel CPUs and GPUs, more
details can be found <a href="https://github.com/oneapi-src/oneDNN">here</a>.

You can find performance numbers in the
<a href="https://mxnet.apache.org/versions/1.7.0/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

To install native MXNet without oneDNN, run the following command:

{% highlight bash %}
pip install mxnet-native==1.7.0
{% endhighlight %}

</div> <!-- End of v1-7-0 -->

<div class="v1-6-0">
{% highlight bash %}
pip install mxnet==1.6.0
{% endhighlight %}

MKL-DNN enabled pip packages are optimized for Intel hardware. You can find
performance numbers in the
<a href="https://mxnet.apache.org/versions/1.6/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

{% highlight bash %}
pip install mxnet-mkl==1.6.0
{% endhighlight %}

</div> <!-- End of v1-6-0 -->

<div class="v1-5-1">
{% highlight bash %}
pip install mxnet==1.5.1
{% endhighlight %}

MKL-DNN enabled pip packages are optimized for Intel hardware. You can find
performance numbers in the
<a href="https://mxnet.apache.org/versions/1.6/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

{% highlight bash %}
pip install mxnet-mkl==1.5.1
{% endhighlight %}

</div> <!-- End of v1-5-1 -->

<div class="v1-4-1">

{% highlight bash %}
pip install mxnet==1.4.1
{% endhighlight %}

MKL-DNN enabled pip packages are optimized for Intel hardware. You can find
performance numbers in the
<a href="https://mxnet.apache.org/versions/1.6/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

{% highlight bash %}
pip install mxnet-mkl==1.4.1
{% endhighlight %}

</div> <!-- End of v1-4-1 -->
<div class="v1-3-1">

{% highlight bash %}
pip install mxnet==1.3.1
{% endhighlight %}

MKL-DNN enabled pip packages are optimized for Intel hardware. You can find
performance numbers in the
<a href="https://mxnet.apache.org/versions/1.6/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

{% highlight bash %}
pip install mxnet-mkl==1.3.1
{% endhighlight %}

</div> <!-- End of v1-3-1 -->
<div class="v1-2-1">

{% highlight bash %}
pip install mxnet==1.2.1
{% endhighlight %}

MKL-DNN enabled pip packages are optimized for Intel hardware. You can find
performance numbers in the
<a href="https://mxnet.apache.org/versions/1.6/api/faq/perf.html#intel-cpu">
MXNet tuning guide</a>.

{% highlight bash %}
pip install mxnet-mkl==1.2.1
{% endhighlight %}

</div> <!-- End of v1-2-1 -->

<div class="v1-1-0">

{% highlight bash %}
pip install mxnet==1.1.0
{% endhighlight %}

</div> <!-- End of v1-1-0-->

<div class="v1-0-0">

{% highlight bash %}
pip install mxnet==1.0.0
{% endhighlight %}

</div> <!-- End of v1-0-0-->


<div class="v0-12-1">

{% highlight bash %}
pip install mxnet==0.12.1
{% endhighlight %}

For MXNet 0.12.0:

{% highlight bash %}
pip install mxnet==0.12.0
{% endhighlight %}

</div> <!-- End of v0-12-1-->

<div class="v0-11-0">

{% highlight bash %}
pip install mxnet==0.11.0
{% endhighlight %}

</div> <!-- End of v0-11-0-->

<br>


{% include /get_started/pip_snippet.md %}
